@@ -114,6 +114,14 @@ get_goos() {
 	cygwin_nt*) goos="windows" ;;
 	mingw*) goos="windows" ;;
 	msys_nt*) goos="windows" ;;
+	sunos*)
+		kernel=$(uname -o | tr '[:upper:]' '[:lower:]')
+		case "${kernel}" in
+		illumos*) goos="illumos" ;;
+		solaris*) goos="solaris" ;;
+		*) goos="${os}" ;;
+		esac
+		;;
 	*) goos="${os}" ;;
 	esac
 	echo "${goos}"
@@ -127,6 +135,7 @@ get_goarch() {
 	armv*) goarch="arm" ;;
 	i386) goarch="i386" ;;
 	i686) goarch="i386" ;;
+	i86pc) goarch="amd64" ;;
 	x86) goarch="i386" ;;
 	x86_64) goarch="amd64" ;;
 	*) goarch="${arch}" ;;
@@ -142,6 +151,7 @@ check_goos_goarch() {
 	freebsd/amd64) return 0 ;;
 	freebsd/arm) return 0 ;;
 	freebsd/arm64) return 0 ;;
+	illumos/amd64) return 0 ;;
 	linux/386) return 0 ;;
 	linux/amd64) return 0 ;;
 	linux/arm) return 0 ;;
@@ -152,6 +162,7 @@ check_goos_goarch() {
 	openbsd/amd64) return 0 ;;
 	openbsd/arm) return 0 ;;
 	openbsd/arm64) return 0 ;;
+	solaris/amd64) return 0 ;;
 	windows/386) return 0 ;;
 	windows/amd64) return 0 ;;
 	windows/arm) return 0 ;;
