@@ -10,6 +10,8 @@ import (
 	"path/filepath"
 	"regexp"
 	"strings"
+
+	"github.com/coreos/go-semver/semver"
 )
 
 var (
@@ -87,6 +89,12 @@ var knownPrefixedFiles = newStringSet(
 	VersionName,
 )
 
+// knownPrefixedDirs is a set of known dirnames with the .chezmoi prefix.
+var knownPrefixedDirs = newStringSet(
+	scriptsDirName,
+	templatesDirName,
+)
+
 var modeTypeNames = map[fs.FileMode]string{
 	0:                 "file",
 	fs.ModeDir:        "dir",
@@ -97,6 +105,17 @@ var modeTypeNames = map[fs.FileMode]string{
 	fs.ModeCharDevice: "char device",
 }
 
+// A TooOldErrror is returned when the source state requires a newer version of
+// chezmoi.
+type TooOldError struct {
+	Have semver.Version
+	Need semver.Version
+}
+
+func (e *TooOldError) Error() string {
+	return fmt.Sprintf("source state requires version %s or later, chezmoi is version %s", e.Need, e.Have)
+}
+
 type inconsistentStateError struct {
 	targetRelPath RelPath
 	origins       []string
@@ -145,7 +164,7 @@ func SuspiciousSourceDirEntry(base string, fileInfo fs.FileInfo) bool {
 	case 0:
 		return strings.HasPrefix(base, Prefix) && !knownPrefixedFiles.contains(base)
 	case fs.ModeDir:
-		return strings.HasPrefix(base, Prefix) && base != templatesDirName
+		return strings.HasPrefix(base, Prefix) && !knownPrefixedDirs.contains(base)
 	case fs.ModeSymlink:
 		return strings.HasPrefix(base, Prefix)
 	default:
