@@ -8,6 +8,7 @@ import (
 
 type applyCmdConfig struct {
 	exclude   *chezmoi.EntryTypeSet
+	init      bool
 	include   *chezmoi.EntryTypeSet
 	recursive bool
 }
@@ -28,6 +29,7 @@ func (c *Config) newApplyCmd() *cobra.Command {
 	flags := applyCmd.Flags()
 	flags.VarP(c.apply.exclude, "exclude", "x", "Exclude entry types")
 	flags.VarP(c.apply.include, "include", "i", "Include entry types")
+	flags.BoolVar(&c.apply.init, "init", c.update.init, "Recreate config file from template")
 	flags.BoolVarP(&c.apply.recursive, "recursive", "r", c.apply.recursive, "Recurse into subdirectories")
 
 	return applyCmd
@@ -36,6 +38,7 @@ func (c *Config) newApplyCmd() *cobra.Command {
 func (c *Config) runApplyCmd(cmd *cobra.Command, args []string) error {
 	return c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, args, applyArgsOptions{
 		include:      c.apply.include.Sub(c.apply.exclude),
+		init:         c.apply.init,
 		recursive:    c.apply.recursive,
 		umask:        c.Umask,
 		preApplyFunc: c.defaultPreApplyFunc,
