@@ -2,6 +2,6 @@ package cmd
 
 import "github.com/twpayne/chezmoi/v2/internal/chezmoi"
 
-func (c *umaskCheck) Run(system chezmoi.System) (checkResult, string) {
+func (c *umaskCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	return checkResultSkipped, ""
 }
