@@ -19,6 +19,15 @@ type ioregData struct {
 	value map[string]interface{}
 }
 
+func (c *Config) fromYamlTemplateFunc(s string) interface{} {
+	var data interface{}
+	if err := chezmoi.FormatYAML.Unmarshal([]byte(s), &data); err != nil {
+		returnTemplateError(err)
+		return nil
+	}
+	return data
+}
+
 func (c *Config) includeTemplateFunc(filename string) string {
 	var absPath chezmoi.AbsPath
 	if path.IsAbs(filename) {
@@ -120,6 +129,15 @@ func (c *Config) statTemplateFunc(name string) interface{} {
 	}
 }
 
+func (c *Config) toYamlTemplateFunc(data interface{}) string {
+	yaml, err := chezmoi.FormatYAML.Marshal(data)
+	if err != nil {
+		returnTemplateError(err)
+		return ""
+	}
+	return string(yaml)
+}
+
 func returnTemplateError(err error) {
 	panic(err)
 }
