@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"io"
+	"io/fs"
 	"os"
 
 	"golang.org/x/sys/windows"
@@ -44,3 +45,7 @@ func enableVirtualTerminalProcessing(w io.Writer) error {
 	}
 	return windows.SetConsoleMode(windows.Handle(file.Fd()), dwMode|windows.ENABLE_VIRTUAL_TERMINAL_PROCESSING)
 }
+
+func fileInfoUID(fs.FileInfo) int {
+	return 0
+}
